@@ -47,6 +47,10 @@
 #define AV_COMPAT_CODEC_DEPRECATED
 #endif
 
+#if LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(58, 9, 100)
+#define AV_API_NEXT_CHANGES
+#endif
+
 // This is a list of extensions that are never handled by this backend
 // It is not a complete list of audio formats supported by ffmpeg,
 // only those I recognized right away.
@@ -404,13 +408,22 @@ static gboolean _is_ignored_extension(const char *extension) {/*{{{*/
 	return FALSE;
 }/*}}}*/
 void file_type_libav_initializer(file_type_handler_t *info) {/*{{{*/
+#ifndef AV_API_NEXT_CHANGES
     avcodec_register_all();
 	av_register_all();
+#else
+	void *opaque_iter = NULL;
+#endif
 	avformat_network_init();
 
 	// Register all file formats supported by libavformat
 	info->file_types_handled = gtk_file_filter_new();
-	for(AVInputFormat *iter = av_iformat_next(NULL); iter; iter = av_iformat_next(iter)) {
+#ifndef AV_API_NEXT_CHANGES
+	for(AVInputFormat *iter = av_iformat_next(NULL); iter; iter = av_iformat_next(iter))
+#else
+	for(const AVInputFormat *iter; (iter = av_demuxer_iterate(&opaque_iter)); /*nothing */)
+#endif
+	{
 		if(iter->name) {
 			gchar **fmts = g_strsplit(iter->name, ",", -1);
 			for(gchar **fmt = fmts; *fmt; fmt++) {
